==> form_validation-2.0.0%2B2.tar.gz: test/validators/required_validator_test.dart <==
import 'package:flutter_test/flutter_test.dart';
import 'package:form_validation/form_validation.dart';
import 'package:static_translations/static_translations.dart';

const _kBuilder = RequiredValidator.fromDynamic;
const _kType = RequiredValidator.type;

void main() {
  test('json', () {
    try {
      expect(_kBuilder(null), null);
      fail('Expected exception');
    } catch (e) {
      // pass
    }

    try {
      _kBuilder({});
      fail('Expected exception');
    } catch (e) {
      // pass
    }

    try {
      _kBuilder({
        'type': 'foo',
      });
      fail('Expected exception');
    } catch (e) {
      // pass
    }

    expect(
      _kBuilder({
        'type': _kType,
      }) is RequiredValidator,
      true,
    );

    expect(
      _kBuilder({
        'type': _kType,
      }).toJson(),
      {
        'type': _kType,
      },
    );
  });

  testWidgets('validate', (tester) async {
    var translator = Translator.of(null);

    expect(
      RequiredValidator().validate(
        label: 'test',
        translator: translator,
        value: '8005556666',
      ),
      null,
    );
    expect(
      RequiredValidator().validate(
        label: 'test',
        translator: translator,
        value: '800-555-6666',
      ),
      null,
    );
    expect(
      RequiredValidator().validate(
        label: 'test',
        translator: translator,
        value: '(800) 555-6666',
      ),
      null,
    );
    expect(
      RequiredValidator().validate(
        label: 'test',
        translator: translator,
        value: '555-6666',
      ),
      null,
    );
    expect(
      RequiredValidator().validate(
        label: 'test',
        translator: translator,
        value: '+1 22 333 555 4444',
      ),
      null,
    );

    expect(
      RequiredValidator()
          .validate(
            label: 'test',
            translator: translator,
            value: null,
          )
          ?.isNotEmpty,
      true,
    );

    expect(
      RequiredValidator()
          .validate(
            label: 'test',
            translator: translator,
            value: '',
          )
          ?.isNotEmpty,
      true,
    );

    expect(
      RequiredValidator()
          .validate(
            label: 'test',
            translator: translator,
            value: '    ',
          )
          ?.isNotEmpty,
      true,
    );
  });
}

==> form_validation-2.2.1%2B2.tar.gz: test/validators/required_validator_test.dart <==
import 'package:flutter_test/flutter_test.dart';
import 'package:form_validation/form_validation.dart';
import 'package:static_translations/static_translations.dart';

const _kBuilder = RequiredValidator.fromDynamic;
const _kType = RequiredValidator.type;

void main() {
  test('json', () {
    try {
      expect(_kBuilder(null), null);
      fail('Expected exception');
    } catch (e) {
      // pass
    }

    try {
      _kBuilder({});
      fail('Expected exception');
    } catch (e) {
      // pass
    }

    try {
      _kBuilder({
        'type': 'foo',
      });
      fail('Expected exception');
    } catch (e) {
      // pass
    }

    expect(
      _kBuilder({
        'type': _kType,
      }).toJson(),
      {
        'type': _kType,
      },
    );
  });

  testWidgets('validate', (tester) async {
    final translator = Translator.of(null);

    expect(
      RequiredValidator().validate(
        label: 'test',
        translator: translator,
        value: '8005556666',
      ),
      null,
    );
    expect(
      RequiredValidator().validate(
        label: 'test',
        translator: translator,
        value: '800-555-6666',
      ),
      null,
    );
    expect(
      RequiredValidator().validate(
        label: 'test',
        translator: translator,
        value: '(800) 555-6666',
      ),
      null,
    );
    expect(
      RequiredValidator().validate(
        label: 'test',
        translator: translator,
        value: '555-6666',
      ),
      null,
    );
    expect(
      RequiredValidator().validate(
        label: 'test',
        translator: translator,
        value: '+1 22 333 555 4444',
      ),
      null,
    );

    expect(
      RequiredValidator()
          .validate(
            label: 'test',
            translator: translator,
            value: null,
          )
          ?.isNotEmpty,
      true,
    );

    expect(
      RequiredValidator()
          .validate(
            label: 'test',
            translator: translator,
            value: '',
          )
          ?.isNotEmpty,
      true,
    );

    expect(
      RequiredValidator()
          .validate(
            label: 'test',
            translator: translator,
            value: '    ',
          )
          ?.isNotEmpty,
      true,
    );
  });
}
